@@ -1,3 +1,4 @@
+from pprint import pprint
 import tensorflow as tf
 import tensorflow.keras as keras
 from tensorflow.keras import layers
@@ -147,7 +148,7 @@ class CBAD(keras.Model):
     def _batch_norm(self,batch_norm):
         if batch_norm:
             bn=layers.BatchNormalization(name=self._layer_name('batch_norm'))
-        return bn      
+            return bn      
 
 
     def _activation(self,act,config):
@@ -663,6 +664,29 @@ class SegmentClassifier(keras.Model):
 
 
 
+    #
+    # STATIC
+    #
+    @staticmethod
+    def from_config(
+            cfig='blocks',
+            key_path='segment_k3',
+            cfig_dir=load.TFBOX,
+            is_file_path=False,
+            config_string=None,
+            **kwargs):
+        config=load.config(
+            cfig=cfig,
+            key_path=key_path,
+            cfig_dir=cfig_dir,
+            is_file_path=is_file_path,
+            config_string=config_string,
+            **kwargs)
+        print('SegmentClassifier:')
+        pprint(config)
+        return SegmentClassifier(**config)
+
+
     #
     # PUBLIC
     #
@@ -673,6 +697,7 @@ class SegmentClassifier(keras.Model):
             filters_list=None,
             kernel_size=3,
             kernel_size_list=None,
+            output_batch_norm=False,
             output_act=True,
             output_act_config={},
             seperable_preclassification=False,
@@ -708,6 +733,7 @@ class SegmentClassifier(keras.Model):
         self.classifier=CBAD(
                 filters=filters_list[-1],
                 kernel_size=kernel_size_list[-1],
+                batch_norm=output_batch_norm,
                 act=act,
                 act_config=output_act_config,
                 name=self.block_name,
